"""A TUI keylauncher that uses the Textual library."""

######################################################################
# Main app information.
__author__     = "falldeaf"
__copyright__  = "Copyright 2023, falldeaf"
__credits__    = [ "falldeaf" ]
__maintainer__ = "falldeaf"
__email__      = "falldeaf@gmail.com"
__version__    = "1.0.0"
__licence__    = "GPLv3+"

### __init__.py ends here